Module convert

Module convert 

Core Convert Extensions

Useful extensions to core::convert library.

Traits

To
Simple and safe type conversions to self. Relies on reciprocals From and Into, so as a consequence the implementation of at least one of them is required.
TryTo
Simple and safe type conversions to self that may fail in a controlled way under some circunstances. Relies on reciprocals TryFrom and TryInto, so as a consequence the implementation of at least one of them is required.